@@ -13,6 +13,7 @@ import (
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
 	"github.com/opentofu/opentofu/internal/addrs"
+	"github.com/opentofu/opentofu/internal/communicator/shared"
 	"github.com/opentofu/opentofu/internal/configs"
 	"github.com/opentofu/opentofu/internal/configs/configschema"
 	"github.com/opentofu/opentofu/internal/dag"
@@ -88,7 +89,7 @@ type NodeAbstractResource struct {
 	// Set from GraphNodeTargetable
 	Excludes []addrs.Targetable
 
-	// Set from AttachDataResourceDependsOn
+	// Set from AttachResourceDependsOn
 	dependsOn      []addrs.ConfigResource
 	forceDependsOn bool
 
@@ -114,18 +115,18 @@ type NodeAbstractResource struct {
 }
 
 var (
-	_ GraphNodeReferenceable               = (*NodeAbstractResource)(nil)
-	_ GraphNodeReferencer                  = (*NodeAbstractResource)(nil)
-	_ GraphNodeProviderConsumer            = (*NodeAbstractResource)(nil)
-	_ GraphNodeProvisionerConsumer         = (*NodeAbstractResource)(nil)
-	_ GraphNodeConfigResource              = (*NodeAbstractResource)(nil)
-	_ GraphNodeAttachResourceConfig        = (*NodeAbstractResource)(nil)
-	_ GraphNodeAttachResourceSchema        = (*NodeAbstractResource)(nil)
-	_ GraphNodeAttachProvisionerSchema     = (*NodeAbstractResource)(nil)
-	_ GraphNodeAttachProviderMetaConfigs   = (*NodeAbstractResource)(nil)
-	_ GraphNodeTargetable                  = (*NodeAbstractResource)(nil)
-	_ graphNodeAttachDataResourceDependsOn = (*NodeAbstractResource)(nil)
-	_ dag.GraphNodeDotter                  = (*NodeAbstractResource)(nil)
+	_ GraphNodeReferenceable             = (*NodeAbstractResource)(nil)
+	_ GraphNodeReferencer                = (*NodeAbstractResource)(nil)
+	_ GraphNodeProviderConsumer          = (*NodeAbstractResource)(nil)
+	_ GraphNodeProvisionerConsumer       = (*NodeAbstractResource)(nil)
+	_ GraphNodeConfigResource            = (*NodeAbstractResource)(nil)
+	_ GraphNodeAttachResourceConfig      = (*NodeAbstractResource)(nil)
+	_ GraphNodeAttachResourceSchema      = (*NodeAbstractResource)(nil)
+	_ GraphNodeAttachProvisionerSchema   = (*NodeAbstractResource)(nil)
+	_ GraphNodeAttachProviderMetaConfigs = (*NodeAbstractResource)(nil)
+	_ GraphNodeTargetable                = (*NodeAbstractResource)(nil)
+	_ graphNodeAttachResourceDependsOn   = (*NodeAbstractResource)(nil)
+	_ dag.GraphNodeDotter                = (*NodeAbstractResource)(nil)
 )
 
 // NewNodeAbstractResource creates an abstract resource graph node for
@@ -185,6 +186,8 @@ func (n *NodeAbstractResource) References() []*addrs.Reference {
 		result = append(result, refs...)
 		refs, _ = lang.ReferencesInExpr(addrs.ParseRef, c.ForEach)
 		result = append(result, refs...)
+		refs, _ = lang.ReferencesInExpr(addrs.ParseRef, c.Enabled)
+		result = append(result, refs...)
 
 		if c.ProviderConfigRef != nil && c.ProviderConfigRef.KeyExpression != nil {
 			providerRefs, _ := lang.ReferencesInExpr(addrs.ParseRef, c.ProviderConfigRef.KeyExpression)
@@ -204,7 +207,7 @@ func (n *NodeAbstractResource) References() []*addrs.Reference {
 
 		if c.Managed != nil {
 			if c.Managed.Connection != nil {
-				refs, _ = lang.ReferencesInBlock(addrs.ParseRef, c.Managed.Connection.Config, connectionBlockSupersetSchema)
+				refs, _ = lang.ReferencesInBlock(addrs.ParseRef, c.Managed.Connection.Config, shared.ConnectionBlockSupersetSchema)
 				result = append(result, refs...)
 			}
 
@@ -213,7 +216,7 @@ func (n *NodeAbstractResource) References() []*addrs.Reference {
 					continue
 				}
 				if p.Connection != nil {
-					refs, _ = lang.ReferencesInBlock(addrs.ParseRef, p.Connection.Config, connectionBlockSupersetSchema)
+					refs, _ = lang.ReferencesInBlock(addrs.ParseRef, p.Connection.Config, shared.ConnectionBlockSupersetSchema)
 					result = append(result, refs...)
 				}
 
@@ -454,8 +457,8 @@ func (n *NodeAbstractResource) SetExcludes(excludes []addrs.Targetable) {
 	n.Excludes = excludes
 }
 
-// graphNodeAttachDataResourceDependsOn
-func (n *NodeAbstractResource) AttachDataResourceDependsOn(deps []addrs.ConfigResource, force bool) {
+// graphNodeAttachResourceDependsOn
+func (n *NodeAbstractResource) AttachResourceDependsOn(deps []addrs.ConfigResource, force bool) {
 	n.dependsOn = deps
 	n.forceDependsOn = force
 }
@@ -495,7 +498,7 @@ func (n *NodeAbstractResource) DotNode(name string, opts *dag.DotOpts) *dag.DotN
 // eval is the only change we get to set the resource "each mode" to list
 // in that case, allowing expression evaluation to see it as a zero-element list
 // rather than as not set at all.
-func (n *NodeAbstractResource) writeResourceState(evalCtx EvalContext, addr addrs.AbsResource) (diags tfdiags.Diagnostics) {
+func (n *NodeAbstractResource) writeResourceState(ctx context.Context, evalCtx EvalContext, addr addrs.AbsResource) (diags tfdiags.Diagnostics) {
 	state := evalCtx.State()
 
 	// We'll record our expansion decision in the shared "expander" object
@@ -506,7 +509,7 @@ func (n *NodeAbstractResource) writeResourceState(evalCtx EvalContext, addr addr
 
 	switch {
 	case n.Config != nil && n.Config.Count != nil:
-		count, countDiags := evaluateCountExpression(n.Config.Count, evalCtx, addr)
+		count, countDiags := evaluateCountExpression(ctx, n.Config.Count, evalCtx, addr)
 		diags = diags.Append(countDiags)
 		if countDiags.HasErrors() {
 			return diags
@@ -515,8 +518,18 @@ func (n *NodeAbstractResource) writeResourceState(evalCtx EvalContext, addr addr
 		state.SetResourceProvider(addr, n.ResolvedProvider.ProviderConfig)
 		expander.SetResourceCount(addr.Module, n.Addr.Resource, count)
 
+	case n.Config != nil && n.Config.Enabled != nil:
+		enabled, enabledDiags := evaluateEnabledExpression(ctx, n.Config.Enabled, evalCtx)
+		diags = diags.Append(enabledDiags)
+		if enabledDiags.HasErrors() {
+			return diags
+		}
+
+		state.SetResourceProvider(addr, n.ResolvedProvider.ProviderConfig)
+		expander.SetResourceEnabled(addr.Module, n.Addr.Resource, enabled)
+
 	case n.Config != nil && n.Config.ForEach != nil:
-		forEach, forEachDiags := evaluateForEachExpression(n.Config.ForEach, evalCtx, addr)
+		forEach, forEachDiags := evaluateForEachExpression(ctx, n.Config.ForEach, evalCtx, addr)
 		diags = diags.Append(forEachDiags)
 		if forEachDiags.HasErrors() {
 			return diags
